# Feasibility of Generating Structured Motivational Messages for Tailored Physical Activity Coaching

This repository is meant to reproduce our analyses for the paper "Feasibility of Generating Structured Motivational Messages for Tailored Physical Activity Coaching."

Authored by Ramya P. Ghantasala, Nele Albers, Kristell M. Penfornis, Milon van Vliet, and Willem-Paul Brinkman.


## Contents of This Repository

```
|   ChecklistDataRepositoryReview.pdf
│   Demographic Analysis.Rmd
│   Dockerfile
│   Prior Sensitivity Analysis.Rmd
│   references.bib
│   README.md
│   Scenarios_and_Motivational_Messages.pdf
│   Statistical Analysis.Rmd 
│
└───data
│   │   experiment_data.csv
│   │   Columns explanation.xlsx
│
└───Figures
│   │   comparison_motivational_impact.pdf
│   │   post_fixed_effect_tailoring.pdf
│
└───Reliability_and_Code_Frequencies
│   │   Dockerfile
│   │   Double_Coding_Round2_Coder1_Per_Response_Demotivating.csv
│   │   Double_Coding_Round2_Coder1_Per_Response_Motivating.csv
│   │   Double_Coding_Round2_Coder1.xlsx
│   │   Double_Coding_Round2_Coder2.xlsx
│   │   README.md/README.pdf
│   │   reliability_and_code_frequencies.ipynb
│
└───results
│   │   Demographic Analysis.pdf
│   │   Prior Sensitivity Analysis.pdf 
│   │   Statistical Analysis.pdf
│
└───scripts
│   │   preprocessing.r

```

| File/Folder Name                        | Content                                                                                   |
| ----------------------------------------| ----------------------------------------------------------------------------------------- |
| ChecklistDataRepositoryReview.pdf       | Checklist reviewing the analysis code and data, filled in by Milon van Vliet.             |
| Demographic Analysis.Rmd                | R Markdown file containing analysis of participants' characteristics and demographic data |
| Dockerfile                              | File containing instructions to build Docker image for analysis in R                      |
| Prior Sensitivity Analysis.Rmd          | R Markdown file containing prior sensitivity analysis                                     |
| references.bib                          | References used in the R Markdown files                                                   |
| Scenarios_and_Motivational_Messages.pdf | All scenarios, tailored motivational messages, and generic motivational messages          |
| Statistical Analysis.Rmd                | R Markdown file containing statistical models for analysis                                |
| README.md/README.pdf                    | The file you are currently reading - provides an overview of how to our reproduce analyses|                                                               |
| data/                                   | Folder containing data from the experiment                                                |
| - experiment_data.csv                   | Approved participants' data                                                               |
| - Columns explanation.xlsx              | Explanation of the columns present in experiment_data.csv                                 |
| Figures/                                | Folder containing Figures 3a and 3b                                                       |
| - comparison_motivational_impact.pdf    | Figure 3a                                                                                 |
| - post_fixed_effect_tailoring.pdf       | Figure 3b                                                                                 |
| Reliability_and_Code_Frequencies        | Folder to reproduce our thematic analysis findings                                        |
| results/                                | Folder containing knitted R Markdown files for analyses                                   |
| - Demographic-Analysis.pdf              | Pdf file knit from `Demographic Analysis.Rmd`                                             |
| - Prior-Sensitivity-Analysis.pdf        | Pdf file knit from `Prior Sensitivity Analysis.Rmd`                                       |
| - Statistical-Analysis.pdf              | Pdf file knit from `Statistical Analysis.Rmd`                                             |
| scripts/                                | Folder containing utility R scripts to help with analysis                                 |
| - preprocessing.r                       | Preprocessing script to clean up and organize data                                        |


## Reproducing Bayesian Analyses

### Initial Setup

Pre-requisites:
- Docker (You can follow the instructions [here](https://docs.docker.com/get-docker/))

Note: For best results, always set your current working directory to `analysis/`, i.e., the working directory containing the current README.MD file you're reading.

### Obtaining the Docker Image

You can build the Docker image in one of two ways:
- Pull the Docker image from Docker Hub using the following command:
```
docker pull gbna4/tailored_messages_r
```
OR
- Build the image from the given Dockerfile
- - Ensure Docker daemon is running
- - Open Terminal or Command Prompt
- - Run the following command:
```
docker build -f /path/to/a/Dockerfile -t <DOCKER_IMAGE_NAME> .
```
Replace the `<DOCKER_IMAGE_NAME>` with the name of your docker image. For example, if the name of your docker image is `statistical-analysis-with-r`, your docker command would be `docker build -f /path/to/a/Dockerfile -t statistical-analysis-with-r .`
More information regarding `Dockerfile` and how to build images can be found [here](https://docs.docker.com/engine/reference/builder/)


### Running the Docker Container

Use the following command to run a Docker container from the Docker image you have built from the previous step. 
```
docker run -d -p 8787:8787 -v <PATH_TO_CURRENT_FOLDER>:/home/rstudio/analysis -e PASSWORD=<PASSWORD> <DOCKER_IMAGE_NAME>
```

If you are running a container from the image pulled from Docker Hub, the command should look something like this (replace `<PATH_TO_CURRENT_FOLDER>` with the actual path to your current folder, for instance `/home/users/documents`, and replace `<PASSWORD>` with a password of your choice, for instance, `password`):
```
docker run -d -p 8787:8787 -v /home/users/documents:/home/rstudio/analysis -e PASSWORD=password gbna4/tailored_messages_r
```

- If the container has started successfully, you should see a new container in Docker Desktop under `Containers/Apps`.
- Navigate to `https://localhost:8787`, and you should see a login page for RStudio. Enter `rstudio` as the username, and the password you specified when you ran the container to login. (Try navigating to `localhost:8787` if the above link doesn't work.)
- Voila! You have RStudio running in your browser.


### Knitting Files

You can knit the files from either the command line or from RStudio. The instructions for both are given below.


#### Knitting from the Command Line

To knit the `.RmD` files from the command line of the docker containers, run the following commands:

- `docker ps` # Find the `CONTAINER ID` of the container running RStudio. If you already have the container id, skip to the next step.
- `docker exec -it -w /home/rstudio/analysis <CONTAINER_ID> /bin/bash # This will open a bash shell at /home/rstudio/analysis in the container` # Replace `<CONTAINER_ID>` with the id you obtained in the last step
- `R -e "rmarkdown::render('<NAME_OF_RMD_FILE>', 'pdf_document')"` #Replace `<NAME_OF_RMD_FILE>` with the name of the RmD file you want to knit, and knit the required RmD file


#### Knitting from RStudio

To knit the `.RmD` files from RStudio:

- Navigate to `http://localhost:8787/` after starting the Docker container.
- Open one of the `.RmD` files, and select "Knit to PDF" from the toolbar.


### Results
- The `results/` folder contains the pdfs knit from the Rmd files present in the root folder. To reproduce the results, run the corresponding R Markdown files to inspect the output, or knit to pdf to get the results neatly printed in a pdf format. The knit files will be generated in the `analysis/` folder.


### Tables/Figures and Corresponding Files

| Input File                     | Corresponding Values in the Report                                 | Output Files Generated                                                                                                          
|--------------------------------|--------------------------------------------------------------------|------------------------------------------------------------------------------------------------|
| Demographic Analysis.RmD       | Table in the Supplementary Material                                | Demographic-Analysis.pdf                                                                       |                                                 
| Statistical Analysis.RmD       | Figures 3a and 3b as well as values in the "Results"-section       | Statistical-Analysis.pdf, comparison_motivational_impact.pdf, post_fixed_effect_tailoring.pdf  |                                                                                                                                                                        
| Prior Sensitivity Analysis.RmD | Values in the "Data preparation and analysis strategies"-section   | Prior-Sensitivity-Analysis.pdf                                                                 |                                                                                                                                                               


## Reproducing Thematic Analysis Findings

Navigate to the folder "Reliability_and_Code_Frequencies" and follow the instructions in the README-file therein to reproduce:
   - our Cohen's kappa values reported in the "Data preparation and analysis strategies"-section and the Supplementary Material, and
   - our code frequencies reported in the "Results"-section.
