#author: "Ramya Ghantasala"
#date: 27/09/2022
#Required files: data/experiment_data.csv

library(reshape2)

# Pre-processing Steps
# Removed data which we do not have approval to store, according to the Data Management Plan.
# Mapped language fluency column to binary (0,1) values indicating not fluent in English and fluent in English

setwd("/home/rstudio/analysis/data")

experiment_data <- read.csv('experiment_data.csv')

# Rename Prolific column names for better readability
colnames(experiment_data)[colnames(experiment_data)      
                   %in% c(
            'Gender..new.', 
            'Socioeconomic.Status', 
            'Household.Size', 
            'Personal.Income..GBP.', 
            'Household.Income..GBP.', 
            'Highest.education.level.completed', 
            'Weekly.Exercise', 
            'Smoking.status', 
            'Smoking.frequency')] <- c(
            'gender', 
            'highest_education_level', 
            'household_income',
            'household_size',
            'personal_income', 
            'smoking_frequency',
            'smoking_status',
            'socioeconomic_status', 
            'weekly_exercise')

colnames(experiment_data)[colnames(experiment_data) == 'Q9.1'] <- 'ttm_stage'
experiment_data$ttm_stage <- cut(as.numeric(experiment_data$ttm_stage), 5, labels = c("Maintenance", "Action", "Preparation", "Contemplation", "Precontemplation"))

# Prepare data for statistical analysis
tailoredQuestions <- c(
'Q16.3_1',
'Q19.3_1',
'Q20.3_1',
'Q24.3_1',
'Q25.3_1',
'Q28.3_1',
'Q29.3_1',
'Q32.3_1',
'Q33.3_1',
'Q36.3_1',
'Q37.3_1',
'Q40.3_1',
'Q41.3_1',
'Q44.3_1',
'Q45.3_1',
'Q48.3_1',
'Q49.3_1',
'Q52.3_1',
'Q53.3_1',
'Q55.3_1',
'Q57.3_1',
'Q58.3_1',
'Q61.3_1',
'Q63.3_1',
'Q65.3_1',
'Q66.3_1',
'Q69.3_1',
'Q71.3_1',
'Q73.3_1',
'Q74.3_1',
'Q77.3_1')

genericQuestions <- c(
'Q17.3_1',
'Q18.3_1',
'Q21.3_1',
'Q23.3_1',
'Q26.3_1',
'Q27.3_1',
'Q30.3_1',
'Q31.3_1',
'Q34.3_1',
'Q35.3_1',
'Q38.3_1',
'Q39.3_1',
'Q42.3_1',
'Q43.3_1',
'Q46.3_1',
'Q47.3_1',
'Q50.3_1',
'Q51.3_1',
'Q54.3_1',
'Q56.3_1',
'Q59.3_1',
'Q60.3_1',
'Q62.3_1',
'Q64.3_1',
'Q67.3_1',
'Q68.3_1',
'Q70.3_1',
'Q72.3_1',
'Q75.3_1',
'Q76.3_1'
)

# Extract anonymized participant id and ratings of tailored questions
motivationTailored <- experiment_data[c('pid',tailoredQuestions)]
# Label tailored message type as 1
motivationTailored$messageType <- 1
# Combine motivational ratings, tailored questions and their label
motivationTailored <- melt(motivationTailored, na.rm = TRUE, id = c("pid", "messageType"), value.name="motivation")
# Remove empty ratings
motivationTailored <- motivationTailored[!(is.na(motivationTailored$motivation) | motivationTailored$motivation ==""),]

# Extract anonymized participant id and ratings of generic questions
motivationGeneric <- experiment_data[c('pid',genericQuestions)]
# Label generic message type as 0
motivationGeneric$messageType <- 0
# Combine motivational ratings, generic questions and their label
motivationGeneric <- melt(motivationGeneric, na.rm = TRUE, id = c("pid", "messageType"), value.name="motivation")
# Remove empty ratings
motivationGeneric <- motivationGeneric[!(is.na(motivationGeneric$motivation) | motivationGeneric$motivation ==""),]

# Combine generic and tailored motivational ratings along with the respective anonymized participant IDs
combinedMotivation <- data.frame(pid = factor(), motivationTailored = integer(), motivationGeneric = integer())
combinedMotivation <- motivationTailored[c(1:2, 4)]
combinedMotivation <- rbind(motivationTailored[c(1:2, 4)], motivationGeneric[c(1:2, 4)])
combinedMotivation$motivation <- as.numeric(combinedMotivation$motivation)
